Extracts and concatenates the regression coefficients from all fitted Q-function models across all regimes and stages.
Arguments
- q_all
A list of fitted outcome regression objects for each regime, as returned by
estimate_values.
Extracts and concatenates the regression coefficients from all fitted Q-function models across all regimes and stages.
A list of fitted outcome regression objects for each regime,
as returned by estimate_values.