Fits a propensity score model at a single stage of the SMART and returns the fitted probabilities. The probability that each individual received the treatment they actually received is computed.
Arguments
- pmodel
A
modelObjobject specifying the propensity score model (typically a binomial GLM).- data
A data frame of individuals to fit the model on (typically those who have reached stage
k).- response
A vector or data frame column of treatment assignments at stage
k.- k
An integer indicating the stage number.